@@ -72,18 +72,18 @@ Arguments:
   arguments        Optional arguments for command.
 
 </source>
-        <translation>Usage: %1 Option [Commande [Arguments...]]
+        <translation>Usage : %1 option [commande [arguments...]]
 
 Interface graphique pour %2/%3
 
-Arguments:
-  Option:
+Arguments :
+  option :
     -h|--help      Affiche cette aide.
     -v|--version   Affiche la version.
-    -s|--su        Utilise %3(1) comme Backend.
-    -d|--sudo      Utilise %2(8) comme Backend.
-  Commande        Commande à exécuter.
-  Arguments        Arguments de la commande à exécuter.
+    -s|--su        Utiliser %3(1) comme backend.
+    -d|--sudo      Utiliser %2(8) comme backend.
+  command        Commande à exécuter.
+  arguments        Arguments optionnels pour la commande.
 
 </translation>
     </message>
@@ -100,17 +100,17 @@ Arguments:
     <message>
         <location filename="../sudo.cpp" line="195"/>
         <source>%1: no command to run provided!</source>
-        <translation>%1: aucune commande à exécuter n&apos;a été spécifiée !</translation>
+        <translation>%1 : aucune commande n&apos;a été spécifiée !</translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="202"/>
         <source>%1: no backend chosen!</source>
-        <translation>%1: aucun Backend n&apos;a été choisi !</translation>
+        <translation>%1 : aucun Backend n&apos;a été choisi !</translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="219"/>
         <source>Syscall error, failed to fork: %1</source>
-        <translation>Erreur d&apos;appel système, échec de la conversion: %1</translation>
+        <translation>Erreur d&apos;appel système, échec de la conversion : %1</translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="246"/>
@@ -122,24 +122,24 @@ Arguments:
         <location filename="../sudo.cpp" line="295"/>
         <source>%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!
 </source>
-        <translation>%1: Tentative détectée d&apos;injection d&apos;une commande privilégiée via LC_ALL env(%2). En sortant!
+        <translation>%1 : Tentative détectée d&apos;injection d&apos;une commande privilégiée via LC_ALL env(%2). En sortant !
 </translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="337"/>
         <source>Syscall error, failed to bring pty to non-block mode: %1</source>
-        <translation>Erreur d&apos;appel système, échec du transfert de pty en mode sans blocage: %1</translation>
+        <translation>Erreur d&apos;appel système, échec du transfert de pty en mode sans blocage : %1</translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="345"/>
         <source>Syscall error, failed to fdopen pty: %1</source>
-        <translation>Erreur d&apos;appel système, échec de fdopen pty: %1</translation>
+        <translation type="unfinished">Erreur d&apos;appel système, échec de fdopen pty : %1</translation>
     </message>
     <message>
         <location filename="../sudo.cpp" line="314"/>
         <source>%1: Failed to exec &apos;%2&apos;: %3
 </source>
-        <translation>%1: Impossible d&apos;exécuter &apos;%2&apos;: %3
+        <translation>%1 : Impossible d&apos;exécuter &apos;%2&apos; : %3
 </translation>
     </message>
     <message>
